@@ -69,7 +69,10 @@ sub run_program {
     local $ENV{PERLDB_OPTS} = $port ?
         "RemotePort=localhost:$port $opts" :
         "RemotePath=$path $opts";
-    local $ENV{PERL5LIB} = $ENV{PERL5LIB} ? ".:$ENV{PERL5LIB}" : ".";
+    # the harness/blib don't add dbgp-helper to the path
+    local $ENV{PERL5LIB} = join ':', qw(blib/lib/dbgp-helper blib/arch),
+                                     ($ENV{PERL5LIB}) x !!$ENV{PERL5LIB}
+        if grep /blib/, @INC;
     $PID = IPC::Open3::open3(
         $CHILD_IN, $CHILD_OUT, $CHILD_ERR,
         $^X, '-d', $script,
@@ -136,8 +139,14 @@ sub eval_value_is {
 
     my ($expr, $value) = @_;
     my $res = send_command('eval', encode_base64($expr));
+    my $eval_type = $res->result->type;
+    my $eval_value = $res->result->value;
 
-    is($res->result->value, $value);
+    # workaround for current client behaviour
+    is($eval_type eq 'undef' ? undef :
+       defined $eval_value   ? $eval_value :
+                          '',
+       $value);
 }
 
 sub breakpoint_list_is {
